@@ -5,6 +5,11 @@ from typing import Any, Optional
 
 from pydantic import BaseModel
 
+from rowantree.auth.sdk.commands.authenticate_user import AuthenticateUserCommand
+from rowantree.auth.sdk.config.auth import AuthConfig
+from rowantree.auth.sdk.contracts.dto.authenticate_user_request import AuthenticateUserRequest
+from rowantree.auth.sdk.contracts.dto.token import Token
+
 from ..common.config import Config
 
 
@@ -28,8 +33,6 @@ class AbstractCommand(BaseModel):
 
     def __init__(self, **data: Any):
         super().__init__(**data)
-        if "API-ACCESS-KEY" not in self.headers:
-            self.headers["API-ACCESS-KEY"] = self.config.access_key
 
     @abstractmethod
     def execute(self, *args, **kwargs) -> Optional[Any]:
